import { DeepClient, SerialOperation } from '@deep-foundation/deeplinks/imports/client';
import { DeviceInfo } from './device-info';
/**
  * Gets serial operations to insert Device
  *
  * @example
 ```ts
 const serialOperations = await getDeviceInsertSerialOperations({
   deep
 });
 await deep.serial({
   operations: serialOperations
 })
 ```
  */
export declare function getDeviceInsertSerialOperations(param: GetDeviceInsertSerialOperationsParam): Promise<Array<SerialOperation>>;
export interface GetDeviceInsertSerialOperationsParam {
    /**
     * Reserved link ids that will be used in the serial operations
     */
    reservedLinkIds?: {
        /**
         * Reserved link id for the device
         */
        deviceLinkId: number;
        /**
         * Reserved link id for the contain
         */
        containLinkId: number;
    };
    /**
     * Link ids of types that will be used in the serial operations
     */
    typeLinkIds?: {
        /**
         * Link id of the contain type
         */
        containTypeLinkId?: number;
        /**
         * Link id of the device type
         */
        deviceTypeLinkId?: number;
    };
    /**
     * Deep Client
     */
    deep: DeepClient;
    /**
     * Device Info
     *
     * @defaultValue result of {@link getAllDeviceInfo} if not provided or undefined
     */
    info?: DeviceInfo;
    /**
     * Link id of the container
     *
     * @remarks
     * If it is null, contain link will not be created
     * @defaultValue {@link GetDeviceInsertSerialOperationsParam.deep.linkId} if not provided or undefined
     */
    containerLinkId?: number | undefined | null;
    /**
     * Value of the contain link
     *
     * @remarks
     * If {@link GetDeviceInsertSerialOperationsParam.containerLinkId} is null, this will be ignored
     */
    containValue?: string | undefined;
}
