import { createSerialOperation } from '@deep-foundation/deeplinks/imports/gql';
import { getAllDeviceInfo } from './get-all-device-info';
import { Package } from './package';
/**
  * Gets serial operations to insert Device
  *
  * @example
 ```ts
 const serialOperations = await getDeviceInsertSerialOperations({
   deep
 });
 await deep.serial({
   operations: serialOperations
 })
 ```
  */
export async function getDeviceInsertSerialOperations(param) {
    const { deep, info = await getAllDeviceInfo(), containValue, containerLinkId, } = param;
    const $package = new Package({ deep });
    const { containLinkId, deviceLinkId } = await getReservedLinkIds();
    const { containTypeLinkId, deviceTypeLinkId } = await getTypeLinkIds();
    const serialOperations = [];
    const deviceInsertSerialOperation = createSerialOperation({
        type: 'insert',
        table: 'links',
        objects: {
            id: deviceLinkId,
            type_id: deviceTypeLinkId,
        },
    });
    serialOperations.push(deviceInsertSerialOperation);
    const valueOfDeviceInsertSerialOperation = createSerialOperation({
        type: 'insert',
        table: 'objects',
        objects: {
            link_id: deviceLinkId,
            value: info,
        },
    });
    serialOperations.push(valueOfDeviceInsertSerialOperation);
    if (containerLinkId !== null) {
        const containInsertSerialOperation = createSerialOperation({
            type: 'insert',
            table: 'links',
            objects: {
                type_id: containTypeLinkId,
                from_id: containerLinkId || deep.linkId,
                to_id: deviceLinkId,
            },
        });
        serialOperations.push(containInsertSerialOperation);
        const valueOfContainInsertSerialOperation = createSerialOperation({
            type: 'insert',
            table: 'strings',
            objects: {
                link_id: containLinkId,
                value: containValue,
            },
        });
        serialOperations.push(valueOfContainInsertSerialOperation);
    }
    return serialOperations;
    async function getReservedLinkIds() {
        let result = {
            containLinkId: 0,
            deviceLinkId: 0,
        };
        const linksToReserveCount = Object.keys(result).length -
            Object.keys(param.reservedLinkIds || {}).length;
        const reservedLinkIds = linksToReserveCount > 0 ? await deep.reserve(linksToReserveCount) : [];
        result = {
            containLinkId: param.reservedLinkIds?.containLinkId ?? reservedLinkIds.pop(),
            deviceLinkId: param.reservedLinkIds?.deviceLinkId ?? reservedLinkIds.pop(),
        };
        return result;
    }
    async function getTypeLinkIds() {
        const result = {
            containTypeLinkId: param.typeLinkIds?.containTypeLinkId ||
                (await deep.id('@deep-foundation/core', 'Contain')),
            deviceTypeLinkId: param.typeLinkIds?.deviceTypeLinkId ||
                (await $package.Device.id()),
        };
        return result;
    }
}
