import { createSerialOperation } from '@deep-foundation/deeplinks/imports/gql';
import { getAllDeviceInfo } from './get-all-device-info';
/**
  * Gets serial operations to insert Device
  *
  * @example
 ```ts
 const serialOperations = await getDeviceValueInsertSerialOperations({
   deep
 });
 await deep.serial({
   operations: serialOperations
 })
 ```
  */
export async function getDeviceValueUpdateSerialOperations(param) {
    const { deep, info } = param;
    const deviceLink = await getDeviceLink();
    const value = await getValue({
        deviceLink,
        data: info,
    });
    const serialOperations = await getSerialOperations({
        deviceLink,
        value,
    });
    return serialOperations;
    async function getDeviceLink() {
        let deviceLink;
        if ('deviceLinkId' in param) {
            if (!param.deviceLinkId) {
                throw new Error(`deviceLinkId is undefined`);
            }
            const { data } = await deep.select({
                id: param.deviceLinkId,
            });
            deviceLink = data[0];
        }
        else if ('deviceLink' in param) {
            if (!param.deviceLink) {
                throw new Error(`deviceLink is undefined`);
            }
            deviceLink = param.deviceLink;
        }
        else {
            throw new Error(`Either deviceLink or deviceLinkId must be passed`);
        }
        return deviceLink;
    }
    async function getValueInsertSerialOperation({ deviceLink, value, }) {
        return createSerialOperation({
            table: 'objects',
            type: 'insert',
            objects: {
                link_id: deviceLink.id,
                value: value,
            },
        });
    }
    async function getValueUpdateSerialOperation({ deviceLink, value, }) {
        return createSerialOperation({
            table: 'objects',
            type: 'update',
            exp: {
                link_id: deviceLink.id,
            },
            value: {
                value: value,
            },
        });
    }
    async function getValue({ deviceLink, data, }) {
        return {
            ...(deviceLink.value?.value ?? {}),
            ...(data ?? (await getAllDeviceInfo())),
        };
    }
    async function getSerialOperations({ deviceLink, value, }) {
        let serialOperations = [];
        if (!deviceLink.value) {
            serialOperations.push(await getValueUpdateSerialOperation({
                deviceLink,
                value,
            }));
        }
        else {
            serialOperations.push(await getValueInsertSerialOperation({
                deviceLink,
                value,
            }));
        }
        return serialOperations;
    }
}
