import { useEffect, useState } from 'react';
/**
 * A custom React Hook that checks if a device link exists in the Deep database, and if not, it inserts one. Also saves device information to deep on render.
 *
 * @remarks
 * If the passed {@link UseDeviceInsertionIfDoesNotExistAndSavingInfoParam.deviceLinkId} is not undefined, the hook verifies its existence in Deep. If it does not exist, a new device link is inserted.
 *
 * It is recommended to use {@link WithDeviceInsertionIfDoesNotExistAndSavingData} instead of using this hook directly
 */
export function useDeviceInsertionIfDoesNotExistAndSavingData(param) {
    const { deep, deviceLinkId, containerLinkId, insertDeviceCallback } = param;
    const [isLoading, setIsLoading] = useState(false);
    useEffect(() => {
        const fetchAndInsertDeviceLink = async () => {
            let deviceLink;
            if (deviceLinkId) {
                const { data } = await deep.select(deviceLinkId);
                deviceLink = data[0];
            }
            if (!deviceLinkId || !deviceLink) {
                setIsLoading(true);
                await insertDeviceCallback();
                setIsLoading(false);
            }
        };
        fetchAndInsertDeviceLink();
    }, [deviceLinkId]);
    return { isLoading };
}
